On 2021-Mar-15, Justin Pryzby wrote:

> Are you going to update the assertion ?
> 
> +#if 0                                                                        
>                                                                               
>                                                                        
>         Assert((meta == META_NONE && varprefix == NULL) ||                    
>                                                                               
>                                                                        
>                    ((meta == META_GSET || meta == META_ASET) && varprefix != 
> NULL));                                                                       
>                                                                         
> +#endif                                                                       
>                                                                               
>                                                                        

Yeah, caught that just after sending.  Here's a notpatch.

-- 
Álvaro Herrera                            39°49'30"S 73°17'W
"La virtud es el justo medio entre dos defectos" (Aristóteles)
diff --git a/src/bin/pgbench/pgbench.c b/src/bin/pgbench/pgbench.c
index ba7b35d83c..e69d43b26b 100644
--- a/src/bin/pgbench/pgbench.c
+++ b/src/bin/pgbench/pgbench.c
@@ -2823,13 +2823,12 @@ readCommandResponse(CState *st, MetaCommand meta, char 
*varprefix)
        int                     qrynum = 0;
 
        /*
         * varprefix should be set only with \gset or \aset, and SQL commands do
         * not need it.
and
+        * SQL commands do not need it.
         */
-#if 0
        Assert((meta == META_NONE && varprefix == NULL) ||
+                  ((meta == META_ENDPIPELINE) && varprefix == NULL) ||
                   ((meta == META_GSET || meta == META_ASET) && varprefix != 
NULL));
-#endif
 
        res = PQgetResult(st->con);
 
@@ -2823,13 +2823,12 @@ readCommandResponse(CState *st, MetaCommand meta, char 
 
        /*
-        * varprefix should be set only with \gset or \aset, and SQL commands do
-        * not need it.
+        * varprefix should be set only with \gset or \aset, and \endpipeline 
and

Reply via email to